import type { RootAction, RootState } from '.';
import type { ThunkDispatch } from 'redux-thunk';
export type ValidationServerAction = 'error' | 'warn';
export type ValidationLevel = 'off' | 'moderate' | 'strict';
export declare const VALIDATOR_CHANGED: "validation/VALIDATOR_CHANGED";
interface ValidatorChangedAction {
    type: typeof VALIDATOR_CHANGED;
    validator: string;
}
export declare const VALIDATION_CANCELED: "validation/VALIDATION_CANCELED";
interface ValidationCanceledAction {
    type: typeof VALIDATION_CANCELED;
    validation: Validation;
}
export declare const VALIDATION_SAVE_FAILED: "validation/VALIDATION_SAVE_FAILED";
interface ValidationSaveFailedAction {
    type: typeof VALIDATION_SAVE_FAILED;
    error: null | {
        message: string;
    };
}
export declare const VALIDATION_FETCHED: "validation/VALIDATION_FETCHED";
interface ValidationFetchedAction {
    type: typeof VALIDATION_FETCHED;
    validation: PartialValidation;
}
export declare const VALIDATION_ACTION_CHANGED: "validation/VALIDATION_ACTION_CHANGED";
interface ValidationActionChangedAction {
    type: typeof VALIDATION_ACTION_CHANGED;
    validationAction: ValidationServerAction;
}
export declare const VALIDATION_LEVEL_CHANGED: "validation/VALIDATION_LEVEL_CHANGED";
interface ValidationLevelChangedAction {
    type: typeof VALIDATION_LEVEL_CHANGED;
    validationLevel: ValidationLevel;
}
export declare const SYNTAX_ERROR_OCCURRED: "validation/SYNTAX_ERROR_OCCURRED";
interface SyntaxErrorOccurredAction {
    type: typeof SYNTAX_ERROR_OCCURRED;
    syntaxError: null | {
        message: string;
    };
}
export type ValidationAction = ValidatorChangedAction | ValidationCanceledAction | ValidationSaveFailedAction | ValidationFetchedAction | ValidationActionChangedAction | ValidationLevelChangedAction | SyntaxErrorOccurredAction;
export interface Validation {
    validator: string;
    validationAction: ValidationServerAction;
    validationLevel: ValidationLevel;
    isChanged?: boolean;
    error?: null | {
        message: string;
    };
}
type PartialValidation = Pick<Validation, 'validationAction' | 'validationLevel'> & Partial<Validation>;
export interface ValidationState extends Validation {
    isChanged: boolean;
    syntaxError: null | {
        message: string;
    };
    error: null | {
        message: string;
    };
    prevValidation?: Validation;
}
export declare const INITIAL_STATE: ValidationState;
export declare const checkValidator: (validator: string) => {
    syntaxError: null | {
        message: string;
    };
    validator: Record<string, unknown> | string;
};
export default function reducer(state: ValidationState | undefined, action: RootAction): ValidationState;
export declare const validationActionChanged: (validationAction: ValidationServerAction) => ValidationActionChangedAction;
export declare const validationLevelChanged: (validationLevel: ValidationLevel) => ValidationLevelChangedAction;
export declare const validatorChanged: (validator: string) => ValidatorChangedAction;
export declare const validationFetched: (validation: PartialValidation) => ValidationFetchedAction;
export declare const validationCanceled: (validation: Validation) => ValidationCanceledAction;
export declare const validationSaveFailed: (error: {
    message: string;
}) => ValidationSaveFailedAction;
export declare const syntaxErrorOccurred: (syntaxError: null | {
    message: string;
}) => SyntaxErrorOccurredAction;
export declare const fetchValidation: (namespace: {
    database: string;
    collection: string;
}) => (dispatch: (action: RootAction) => void, getState: () => RootState) => void;
export declare function validationFromCollection(err: null | {
    message: string;
}, { validation, }?: {
    validation?: {
        validationAction?: string;
        validationLevel?: string;
        validator?: null | Record<string, unknown>;
    } | null;
}): Pick<Validation, 'validationAction' | 'validationLevel'> & {
    error?: {
        message: string;
    };
    validator?: Record<string, unknown>;
};
export declare const saveValidation: (validation: Validation) => (dispatch: ThunkDispatch<RootState, unknown, RootAction>, getState: () => RootState) => Promise<void>;
export declare const cancelValidation: () => (dispatch: ThunkDispatch<RootState, unknown, RootAction>, getState: () => RootState) => void;
export declare const activateValidation: () => (dispatch: ThunkDispatch<RootState, unknown, RootAction>, getState: () => RootState) => void;
export {};
//# sourceMappingURL=validation.d.ts.map